@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: helpers.h 3038 2011-03-19 14:38:34Z mdootson $
+// RCS-ID:      $Id: helpers.h 3397 2012-09-30 02:26:07Z mdootson $
 // Copyright:   (c) 2000-2011 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -439,6 +439,8 @@ void FUNCPTR( wxPli_overload_error )( pTHX_ const char* function,
 SV* FUNCPTR( wxPli_create_virtual_evthandler )( pTHX_ wxEvtHandler* object,
                                         const char* classn, bool forcevirtual );
 wxPliSelfRef* FUNCPTR( wxPli_get_selfref )( pTHX_ wxObject* object, bool forcevirtual );
+SV* FUNCPTR( wxPli_object_2_scalarsv )( pTHX_ SV* var, const wxObject* object );
+SV* FUNCPTR( wxPli_namedobject_2_sv )( pTHX_ SV* var, const wxObject* object, const char* package );
 
 #define WXPLI_BOOT_ONCE_( name, xs ) \
 bool name##_booted = false; \
@@ -535,6 +537,8 @@ struct wxPliHelpers
     SV* ( * m_wxPli_create_virtual_evthandler )( pTHX_ wxEvtHandler* object,
                                         const char* cln, bool forcevirtual );
     wxPliSelfRef* ( * m_wxPli_get_selfref )( pTHX_ wxObject*, bool);
+    SV* ( * m_wxPli_object_2_scalarsv )( pTHX_ SV* var, const wxObject* object );
+    SV* ( * m_wxPli_namedobject_2_sv )( pTHX_ SV* var, const wxObject* object, const char* package );
 };
 
 #if wxPERL_USE_THREADS
@@ -579,7 +583,8 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
  &wxPli_av_2_arrayint, &wxPli_set_events, &wxPli_av_2_arraystring, \
  &wxPli_objlist_push, &wxPliOutputStream_ctor, &wxPli_stringarray_push, \
  &wxPli_overload_error, &wxPli_sv_2_wxvariant, \
- &wxPli_create_virtual_evthandler, &wxPli_get_selfref \
+ &wxPli_create_virtual_evthandler, &wxPli_get_selfref, &wxPli_object_2_scalarsv, \
+ &wxPli_namedobject_2_sv \
  }
 
 #if NEEDS_PLI_HELPERS_STRUCT()
@@ -628,6 +633,8 @@ wxPliHelpers name = { &wxPli_sv_2_object, \
   wxPli_sv_2_wxvariant = name->m_wxPli_sv_2_wxvariant; \
   wxPli_create_virtual_evthandler = name->m_wxPli_create_virtual_evthandler; \
   wxPli_get_selfref = name->m_wxPli_get_selfref; \
+  wxPli_object_2_scalarsv = name->m_wxPli_object_2_scalarsv; \
+  wxPli_namedobject_2_sv = name->m_wxPli_namedobject_2_sv; \
   WXPLI_INIT_CLASSINFO();
 
 #else
